import React, { useState, useCallback, useEffect } from 'react';
import { Bot, MessageSquare, Users, ArrowRight, Mail, FormInputIcon as FormIcon, FileInput } from 'lucide-react';
import '@n8n/chat/style.css';
import Footer from '../components/Footer';
import { createChat } from '@n8n/chat';

const AIChatDemo = () => {
  useEffect(() => {
    document.title = 'AI Chat Assistant Demo | Sales Assist AI';
  }, []);

  const [chatError, setChatError] = useState(false);
  const [retryCount, setRetryCount] = useState(0);
  const MAX_RETRIES = 3;

  const initializeChat = useCallback(async () => {
    try {
      await createChat({
        webhookUrl: 'https://build.salesassistai.com/webhook/51194cdd-32dd-4319-b481-77b215e9a45e/chat',
        webhookConfig: {
          method: 'POST',
          headers: {
            'Content-Type': 'application/json',
            'Accept': 'application/json'
          },
          transformPayload: (payload) => ({
            chatInput: `{{ $json.${payload.message} }}`
          })
        },
        data: {
          source: 'chat_demo',
          demo_type: 'ai_chat',
          timestamp: new Date().toISOString()
        },
        target: '#chat-container',
        mode: 'fullscreen',
        showWelcomeScreen: false,
        chatInputKey: 'chatInput',
        initialMessages: [
          'Hi there! 👋',
          'I\'m your Sales Assist AI representative. How can I help you today?'
        ],
        i18n: {
          en: {
            title: 'Sales Assist AI',
            subtitle: 'I\'m here to help you 24/7',
            inputPlaceholder: 'Type your message...',
            getStarted: 'New Conversation'
          }
        }
      });
      setChatError(false);
    } catch (error) {
      console.error('Failed to initialize chat:', error);
      if (retryCount < MAX_RETRIES) {
        setRetryCount(prev => prev + 1);
        // Exponential backoff: 2s, 4s, 8s
        const delay = Math.pow(2, retryCount + 1) * 1000;
        setTimeout(initializeChat, delay);
      } else {
        setChatError(true);
      }
    }
  }, [retryCount]);

  useEffect(() => {
    initializeChat();
  }, [initializeChat]);
  
  const handleRetry = () => {
    setRetryCount(0);
    setChatError(false);
    initializeChat();
  };
  
  const renderChatContainer = () => {
    if (chatError) {
      return (
        <div className="bg-white rounded-3xl border border-primary-100/50 shadow-soft overflow-hidden h-[600px] flex items-center justify-center mx-4">
          <div className="text-center p-8">
            <Bot className="w-12 h-12 text-primary-600 mx-auto mb-4" />
            <h3 className="text-xl font-semibold text-secondary-900 mb-2">
              Chat Temporarily Unavailable
            </h3>
            <p className="text-secondary-600 mb-4">
              Our chat service is currently experiencing technical difficulties. Please try again later.
            </p>
            <button onClick={handleRetry} className="btn-primary">
              Retry Connection
            </button>
          </div>
        </div>
      );
    }

    return (
      <div id="chat-container" className="bg-white rounded-3xl border border-primary-100/50 shadow-soft overflow-hidden h-[600px] mx-4">
      </div>
    );
  };

  return (
    <div>
      <div className="min-h-screen bg-white">
        <div className="container pt-24 pb-12 px-4">
          <div className="text-center mb-12">
            <div className="inline-flex items-center gap-2 px-4 py-2 rounded-full bg-primary-50 border border-primary-100 mb-4">
              <div className="p-1 bg-gradient-to-r from-primary-500 to-primary-600 rounded-full">
                <Bot className="w-4 h-4 text-white" />
              </div>
              <span className="text-sm font-medium text-primary-700">
                AI CHAT DEMO
              </span>
            </div>
            
            <h1 className="text-4xl font-bold text-secondary-900 mb-4">
              Experience Our
              <span className="block text-gradient mt-2">AI Chat Assistant</span>
            </h1>
            <p className="text-xl text-secondary-600 max-w-2xl mx-auto">
              See how our AI handles customer inquiries, qualifies leads, and provides instant support
            </p>
            
            <div className="max-w-3xl mx-auto">
              <div className="bg-primary-50 rounded-2xl p-6 border border-primary-100 mb-12">
                <h3 className="text-lg font-semibold text-primary-900 mb-4">How the Demo Works</h3>
                <ul className="text-left space-y-3 text-primary-700">
                  <li className="flex items-start gap-2">
                    <span className="text-primary-500 font-bold">1.</span>
                    Try interacting with our AI assistant in the chat window below. Ask questions about our services or discuss your needs.
                  </li>
                  <li className="flex items-start gap-2">
                    <span className="text-primary-500 font-bold">2.</span>
                    Experience natural conversations with context awareness and personalized responses.
                  </li>
                  <li className="flex items-start gap-2">
                    <span className="text-primary-500 font-bold">3.</span>
                    This AI can be customized for your website, messaging apps, and social media channels.
                  </li>
                  <li className="flex items-start gap-2">
                    <span className="text-primary-500 font-bold">4.</span>
                    Deploy as a chat widget or integrate directly into your existing communication channels.
                  </li>
                </ul>
              </div>

              {renderChatContainer()}

              <div className="grid grid-cols-1 md:grid-cols-3 gap-6 mt-12">
                <div className="bg-white rounded-2xl p-6 border border-primary-100/50 shadow-soft">
                  <div className="text-primary-600 mb-4">
                    <MessageSquare className="w-8 h-8" />
                  </div>
                  <h3 className="text-lg font-semibold text-secondary-900 mb-2">
                    Natural Conversations
                  </h3>
                  <p className="text-secondary-600">
                    Our AI engages in human-like conversations while maintaining professionalism
                  </p>
                </div>
                
                <div className="bg-white rounded-2xl p-6 border border-primary-100/50 shadow-soft">
                  <div className="text-primary-600 mb-4">
                    <Users className="w-8 h-8" />
                  </div>
                  <h3 className="text-lg font-semibold text-secondary-900 mb-2">
                    Lead Qualification
                  </h3>
                  <p className="text-secondary-600">
                    Automatically qualifies leads through intelligent conversation flows
                  </p>
                </div>
                
                <div className="bg-white rounded-2xl p-6 border border-primary-100/50 shadow-soft">
                  <div className="text-primary-600 mb-4">
                    <Bot className="w-8 h-8" />
                  </div>
                  <h3 className="text-lg font-semibold text-secondary-900 mb-2">
                    24/7 Availability
                  </h3>
                  <p className="text-secondary-600">
                    Provides instant responses and support around the clock
                  </p>
                </div>
              </div>
            </div>
          </div>

          <div className="mt-24">
            <div className="text-center mb-12">
              <h2 className="text-3xl font-bold text-secondary-900 mb-4">
                Flexible Integration
                <span className="block text-gradient mt-2">Options</span>
              </h2>
              <p className="text-lg text-secondary-600 max-w-2xl mx-auto mb-8">
                Our AI assistant can be integrated across all your communication channels for a seamless experience
              </p>
              
              {/* Integration Options Grid */}
              <div className="grid md:grid-cols-3 gap-6 max-w-4xl mx-auto mb-16">
                <div className="group bg-white rounded-2xl p-6 border border-primary-100/50 shadow-soft hover:shadow-lg transition-all">
                  <div className="w-12 h-12 rounded-xl bg-primary-50 flex items-center justify-center mb-4">
                    <MessageSquare className="w-6 h-6 text-primary-600" />
                  </div>
                  <h3 className="text-lg font-semibold text-secondary-900 mb-2">
                    Chat & Messaging
                  </h3>
                  <ul className="space-y-3 text-secondary-600 text-sm">
                    <li className="flex items-center gap-2">
                      <div className="w-6 h-6 rounded-full bg-primary-50 flex items-center justify-center">
                        <MessageSquare className="w-3 h-3 text-primary-600" />
                      </div>
                      Website Chat Widget
                    </li>
                    <li className="flex items-center gap-2">
                      <div className="w-6 h-6 rounded-full bg-primary-50 flex items-center justify-center">
                        <MessageSquare className="w-3 h-3 text-primary-600" />
                      </div>
                      Facebook Messenger
                    </li>
                    <li className="flex items-center gap-2">
                      <div className="w-6 h-6 rounded-full bg-primary-50 flex items-center justify-center">
                        <MessageSquare className="w-3 h-3 text-primary-600" />
                      </div>
                      WhatsApp Business
                    </li>
                    <li className="flex items-center gap-2">
                      <div className="w-6 h-6 rounded-full bg-primary-50 flex items-center justify-center">
                        <MessageSquare className="w-3 h-3 text-primary-600" />
                      </div>
                      SMS Text Messaging
                    </li>
                  </ul>
                </div>
                
                <div className="group bg-white rounded-2xl p-6 border border-primary-100/50 shadow-soft hover:shadow-lg transition-all">
                  <div className="w-12 h-12 rounded-xl bg-primary-50 flex items-center justify-center mb-4">
                    <Mail className="w-6 h-6 text-primary-600" />
                  </div>
                  <h3 className="text-lg font-semibold text-secondary-900 mb-2">
                    Email Integration
                  </h3>
                  <ul className="space-y-3 text-secondary-600 text-sm">
                    <li className="flex items-center gap-2">
                      <div className="w-6 h-6 rounded-full bg-primary-50 flex items-center justify-center">
                        <Mail className="w-3 h-3 text-primary-600" />
                      </div>
                      Smart Email Responses
                    </li>
                    <li className="flex items-center gap-2">
                      <div className="w-6 h-6 rounded-full bg-primary-50 flex items-center justify-center">
                        <Mail className="w-3 h-3 text-primary-600" />
                      </div>
                      Follow-up Sequences
                    </li>
                    <li className="flex items-center gap-2">
                      <div className="w-6 h-6 rounded-full bg-primary-50 flex items-center justify-center">
                        <Mail className="w-3 h-3 text-primary-600" />
                      </div>
                      Newsletter Management
                    </li>
                    <li className="flex items-center gap-2">
                      <div className="w-6 h-6 rounded-full bg-primary-50 flex items-center justify-center">
                        <Mail className="w-3 h-3 text-primary-600" />
                      </div>
                      Support Ticketing
                    </li>
                  </ul>
                </div>
                
                <div className="group bg-white rounded-2xl p-6 border border-primary-100/50 shadow-soft hover:shadow-lg transition-all">
                  <div className="w-12 h-12 rounded-xl bg-primary-50 flex items-center justify-center mb-4">
                    <FileInput className="w-6 h-6 text-primary-600" />
                  </div>
                  <h3 className="text-lg font-semibold text-secondary-900 mb-2">
                    Lead Capture Forms
                  </h3>
                  <ul className="space-y-3 text-secondary-600 text-sm">
                    <li className="flex items-center gap-2">
                      <div className="w-6 h-6 rounded-full bg-primary-50 flex items-center justify-center">
                        <FormIcon className="w-3 h-3 text-primary-600" />
                      </div>
                      Smart Form Assistance
                    </li>
                    <li className="flex items-center gap-2">
                      <div className="w-6 h-6 rounded-full bg-primary-50 flex items-center justify-center">
                        <FormIcon className="w-3 h-3 text-primary-600" />
                      </div>
                      Dynamic Field Validation
                    </li>
                    <li className="flex items-center gap-2">
                      <div className="w-6 h-6 rounded-full bg-primary-50 flex items-center justify-center">
                        <FormIcon className="w-3 h-3 text-primary-600" />
                      </div>
                      Conditional Logic
                    </li>
                    <li className="flex items-center gap-2">
                      <div className="w-6 h-6 rounded-full bg-primary-50 flex items-center justify-center">
                        <FormIcon className="w-3 h-3 text-primary-600" />
                      </div>
                      Auto-Response Handling
                    </li>
                  </ul>
                </div>
              </div>
            </div>

            <div className="grid md:grid-cols-2 gap-8 max-w-4xl mx-auto">
              {/* Popup Widget Example */}
              <div className="relative bg-white rounded-2xl border border-primary-100/50 shadow-soft p-6">
                <div className="relative aspect-video rounded-xl overflow-hidden bg-gradient-to-br from-secondary-50/50 to-white p-4">
                  {/* Website Mockup */}
                  <div className="absolute inset-4 bg-white rounded-lg shadow-sm">
                    {/* Header */}
                    <div className="h-12 bg-secondary-100 rounded-t-lg flex items-center px-4">
                      <div className="w-24 h-4 bg-secondary-200 rounded-full" />
                      <div className="ml-auto flex gap-3">
                        <div className="w-16 h-4 bg-secondary-200 rounded-full" />
                        <div className="w-16 h-4 bg-secondary-200 rounded-full" />
                        <div className="w-16 h-4 bg-secondary-200 rounded-full" />
                      </div>
                    </div>
                    {/* Content */}
                    <div className="p-4 grid gap-4">
                      <div className="h-8 bg-secondary-100 rounded w-3/4" />
                      <div className="grid grid-cols-3 gap-4">
                        <div className="h-24 bg-secondary-100 rounded" />
                        <div className="h-24 bg-secondary-100 rounded" />
                        <div className="h-24 bg-secondary-100 rounded" />
                      </div>
                      <div className="h-32 bg-secondary-100 rounded" />
                    </div>
                  </div>
                  {/* Chat Widget Preview */}
                  <div className="absolute bottom-4 right-4 w-72 bg-white rounded-2xl shadow-xl border border-primary-100/50 transform rotate-3 origin-bottom-right hover:rotate-0 hover:scale-105 transition-all duration-300">
                    <div className="h-14 bg-gradient-to-r from-primary-500 to-primary-600 rounded-t-2xl flex items-center justify-between px-4">
                      <div className="flex items-center gap-2">
                        <Bot className="w-5 h-5 text-white" />
                        <span className="text-sm text-white font-medium">Chat Assistant</span>
                      </div>
                      <button className="w-8 h-8 rounded-full hover:bg-white/10 flex items-center justify-center transition-colors group">
                        <div className="w-4 h-4 flex flex-col items-center justify-center gap-1">
                          <div className="w-4 h-0.5 bg-white/80 rounded-full group-hover:bg-white transition-colors" />
                          <div className="w-4 h-0.5 bg-white/80 rounded-full group-hover:bg-white transition-colors" />
                        </div>
                      </button>
                    </div>
                    <div className="h-96 flex flex-col">
                      <div className="flex-1 p-4 space-y-4 overflow-y-auto">
                        <div className="flex gap-2">
                          <div className="w-8 h-8 rounded-full bg-primary-100 flex items-center justify-center shrink-0">
                            <Bot className="w-5 h-5 text-primary-600" />
                          </div>
                          <div className="bg-secondary-50 rounded-2xl p-3 text-sm max-w-[80%]">
                            Hi! 👋 How can I help you today?
                          </div>
                        </div>
                        <div className="flex gap-2 justify-end">
                          <div className="bg-primary-500 text-white rounded-2xl p-3 text-sm max-w-[80%]">
                            I'd like to learn more about your services
                          </div>
                        </div>
                        <div className="flex gap-2">
                          <div className="w-8 h-8 rounded-full bg-primary-100 flex items-center justify-center shrink-0">
                            <Bot className="w-5 h-5 text-primary-600" />
                          </div>
                          <div className="bg-secondary-50 rounded-2xl p-3 text-sm max-w-[80%]">
                            I'd be happy to tell you about our services! We offer AI-powered marketing automation, chatbots, and more.
                          </div>
                        </div>
                      </div>
                      <div className="p-4 border-t border-secondary-100">
                        <div className="relative">
                          <input
                            type="text"
                            placeholder="Type your message..."
                            className="w-full pl-4 pr-12 py-3 bg-secondary-50 rounded-xl text-sm focus:outline-none focus:ring-2 focus:ring-primary-500/20 border-none placeholder-secondary-400"
                          />
                          <button className="absolute right-2 top-1/2 -translate-y-1/2 w-8 h-8 rounded-lg bg-primary-500 text-white flex items-center justify-center hover:bg-primary-600 transition-colors">
                            <ArrowRight className="w-4 h-4" />
                          </button>
                        </div>
                      </div>
                    </div>
                  </div>
                </div>
                <h3 className="text-xl font-semibold text-secondary-900 mt-6 mb-2">
                  Popup Widget
                </h3>
                <p className="text-secondary-600">
                  A floating chat button that expands into a full chat window when clicked
                </p>
              </div>

              {/* Embedded Chat Example */}
              <div className="relative bg-white rounded-2xl border border-primary-100/50 shadow-soft p-6">
                <div className="relative aspect-video rounded-xl overflow-hidden bg-gradient-to-br from-secondary-50/50 to-white p-4">
                  {/* Website Mockup */}
                  <div className="absolute inset-4 bg-white rounded-lg shadow-sm">
                    {/* Header */}
                    <div className="h-12 bg-secondary-100 rounded-t-lg flex items-center px-4">
                      <div className="w-24 h-4 bg-secondary-200 rounded-full" />
                      <div className="ml-auto flex gap-3">
                        <div className="w-16 h-4 bg-secondary-200 rounded-full" />
                        <div className="w-16 h-4 bg-secondary-200 rounded-full" />
                        <div className="w-16 h-4 bg-secondary-200 rounded-full" />
                      </div>
                    </div>
                    {/* Content with Chat */}
                    <div className="grid grid-cols-2 gap-4 p-4">
                      {/* Left Content */}
                      <div className="space-y-4">
                        <div className="h-8 bg-secondary-100 rounded w-3/4" />
                        <div className="h-24 bg-secondary-100 rounded" />
                        <div className="h-32 bg-secondary-100 rounded" />
                      </div>
                      {/* Right Chat */}
                      <div className="relative h-full">
                        <div className="absolute inset-0 bg-white/90 backdrop-blur rounded-xl border border-primary-100/50 shadow-lg hover:shadow-xl transition-shadow">
                          <div className="h-12 bg-gradient-to-r from-primary-500 to-primary-600 rounded-t-xl flex items-center px-4">
                            <div className="flex items-center gap-2">
                              <Bot className="w-5 h-5 text-white" />
                              <span className="text-sm text-white font-medium">Support Chat</span>
                            </div>
                          </div>
                          <div className="p-4">
                            <div className="space-y-2">
                              <div className="flex gap-2">
                                <div className="w-6 h-6 rounded-full bg-primary-100 flex items-center justify-center">
                                  <Bot className="w-4 h-4 text-primary-600" />
                                </div>
                                <div className="bg-secondary-50 rounded-xl p-2 text-xs max-w-[80%]">
                                  Welcome! How can I assist you today?
                                </div>
                              </div>
                            </div>
                          </div>
                        </div>
                      </div>
                    </div>
                  </div>
                </div>
                <div className="mt-6">
                  <h3 className="text-xl font-semibold text-secondary-900 mb-2">
                    Embedded Chat
                  </h3>
                  <p className="text-secondary-600">
                    Seamlessly integrated into your website's layout as a dedicated section
                  </p>
                </div>
              </div>
            </div>
          </div>
        </div>
      </div>
      <Footer />
    </div>
  );
};

export default AIChatDemo;